# %{ver}, %{rel}, %{name} provided by Makefile
%define ver 4.1.0.11
%define rel 1
%define name lsb-dist-checker

# LSB Compliant packages require the following in ~/.rpmmacros
#%_binary_payload	w9.gzdio

Summary: LSB Distribution Checker
Vendor: ISPRAS
# name, ver, rel are passed in from Makefile so we only have to set them one place
Name: %{name}
Version: %{ver}
Release: %{rel}
Source: %{name}-%{version}.src.tgz
License: GPL
URL: http://www.linuxfoundation.org/collaborate/workgroups/lsb/download
Group: Development/Tools
Buildroot: %{_builddir}/%{name}-root
AutoReqProv: no
Requires: lsb-setup
Obsoletes: lsb-dtk-manager
Provides: lsb-dtk-manager

%description
LSB Distribution Checker wraps all the current LSB test suites into a
user-friendly "single LSB test suite" with unified test management and
analysis capabilities. This facilitates test execution and results analysis
thus making the LSB tests more attractive for upstream developers as well as
making certification process technically more inviting.

%prep
if [ ! -x /opt/lsb/bin/lsbcc ] ; then
    printf "lsbcc not found, required for compilation, aborting\n"
    exit 1
fi

%setup

%build
export LSBCC_BESTEFFORT=1
# Build ptyshell binary
export LSBCC_LSBVERSION=3.1
export CC=/opt/lsb/bin/lsbcc
#export CFLAGS=-fno-stack-protector
cd ptyshell && make clean && make && cd -

# Build man page
[ -d man/man1 ] || mkdir -p man/man1
pod2man man/man1/dist-checker.pl.pod man/man1/dist-checker.pl.1 -r 'The Linux Foundation' -c '' -n dist-checker.pl
pod2man man/man1/dist-checker.pod man/man1/dist-checker.1 -r 'The Linux Foundation' -c '' -n dist-checker
rm -f man/man1/*.pod
rm -f man/man1/*.pod.moblin

%install

rm -rf $RPM_BUILD_ROOT/opt/lsb/test/manager
mkdir -p $RPM_BUILD_ROOT/opt/lsb/test/manager
cp -r LICENSE README bin utils webui $RPM_BUILD_ROOT/opt/lsb/test/manager
cp -rf man $RPM_BUILD_ROOT/opt/lsb
mkdir -p $RPM_BUILD_ROOT/opt/lsb/test/manager/ptyshell
cp ptyshell/ptyshell $RPM_BUILD_ROOT/opt/lsb/test/manager/ptyshell
rm -rf $RPM_BUILD_ROOT/var/opt/lsb/test/manager
mkdir -p $RPM_BUILD_ROOT/var/opt/lsb/test/manager/manifest
cp Manifest $RPM_BUILD_ROOT/var/opt/lsb/test/manager/manifest
mkdir -p $RPM_BUILD_ROOT/var/opt/lsb/test/manager/problem_db
cp problem_db2 $RPM_BUILD_ROOT/var/opt/lsb/test/manager/problem_db
mkdir -p $RPM_BUILD_ROOT/etc/opt/lsb/test/manager
cp config/dc-server.conf.default $RPM_BUILD_ROOT/etc/opt/lsb/test/manager

%files
%defattr(-,root,root)
%doc /opt/lsb/test/manager/README
%doc /opt/lsb/man/man1/dist-checker.pl.1
%doc /opt/lsb/man/man1/dist-checker.1
/opt/lsb/test/manager
%dir /var/opt/lsb
%dir /var/opt/lsb/test
/var/opt/lsb/test/manager
%dir /etc/opt/lsb
%dir /etc/opt/lsb/test
/etc/opt/lsb/test/manager

%post
echo "Installed successfully."
RESULT=0

if [ ! -x /usr/bin/perl ] ; then
	echo
	echo "Warning: Couldn't find /usr/bin/perl."
	echo "Perl is required for Distribution Checker. Please, install it"
	echo "using the tools provided by your distro."
	echo
	RESULT=1
fi

if ! which lsb_release >/dev/null 2>&1; then
	echo
	echo "Warning: Couldn't find the required tool: lsb_release."
	echo "lsb_release should be always present for a LSB compliant distro."
	echo "You could install lsb_release and other LSB components using"
	echo "the tools provided by your distro."
	echo
	RESULT=1
fi

if lsb_release 2>&1 | grep "No LSB modules" >/dev/null 2>&1; then
	echo
	echo "Warning: No LSB modules are available."
	echo "You could install LSB modules using the tools provided by"
	echo "your distro."
	echo
	RESULT=1
fi

if ! which Xvfb >/dev/null 2>&1; then
	echo
	echo "Warning: Couldn't find the required tool: Xvfb (X Virtual Frame Buffer)."
	echo "Xvfb is required for X11 tests for LSB 3.0 and 3.1. If you are going"
	echo "to run these tests or to get certified for these LSB versions,"
	echo "you should install Xvfb using the tools provided by your distribution."
	echo
	RESULT=1
fi

# put out a message
echo "__________________________________________________________________________"
echo "ATTENTION!"
echo
echo "This tool runs as the root user and installs packages on its own!"
echo "Therefore it can do pretty much harm if it gets out of control."
echo "We have tried to make the script reasonably safe but there is no warranty."
echo "Use it at YOUR OWN RISK only, and only if you know what you are doing."
echo
echo "Some setuid and setgid binaries may be generated and left behind after"
echo "execution of the test suites (especially if certain tests fail)."
echo "You should not install this package on production systems"
echo "or in situations where local users are not completely trusted."
echo
echo "PLEASE DO NOT RUN IT ON A MACHINE THAT HOLDS IMPORTANT DATA, OR PROVIDES"
echo "IMPORTANT SERVICES!"
echo "__________________________________________________________________________"
echo
echo "LSB Distribution Checker has been installed to"
echo "/opt/lsb/test/manager."
if [ $RESULT -ne 0 ]; then
	echo
	echo "There were warnings."
fi
echo
echo "Use /opt/lsb/test/manager/bin/dist-checker-start.pl to run the Distribution Checker."
echo
echo "Read more info at"
echo "http://ispras.linuxbase.org/index.php/About_Distribution_Checker"
echo

# End of the postinstall script.

%postun
if [ $1 = "0" -o $1 = "remove" ]; then
	rm -rf /var/opt/lsb/test/manager/manifest
	rm -rf /var/opt/lsb/test/manager/problem_db
	echo " LSB Distribution Checker has been uninstalled."
	if [ -d /var/opt/lsb/test/manager -a -n "`ls /var/opt/lsb/test/manager`" ]; then
		echo " There are files left in /var/opt/lsb/test/manager. You could delete them all."
	fi
fi

%clean
if [ -e "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then
    rm -rf ${RPM_BUILD_ROOT}
fi
